==> rtorrent-0.6.0.tar.gz: rtorrent-0.6.0/src/ui/element_chunks_seen.h <==
// rTorrent - BitTorrent client
// Copyright (C) 2005-2006, Jari Sundell
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// In addition, as a special exception, the copyright holders give
// permission to link the code of portions of this program with the
// OpenSSL library under certain conditions as described in each
// individual source file, and distribute linked combinations
// including the two.
//
// You must obey the GNU General Public License in all respects for
// all of the code used other than OpenSSL.  If you modify file(s)
// with this exception, you may extend this exception to your version
// of the file(s), but you are not obligated to do so.  If you do not
// wish to do so, delete this exception statement from your version.
// If you delete this exception statement from all source files in the
// program, then also delete it here.
//
// Contact:  Jari Sundell <jaris@ifi.uio.no>
//
//           Skomakerveien 33
//           3185 Skoppum, NORWAY

#ifndef RTORRENT_UI_ELEMENT_CHUNKS_SEEN_H
#define RTORRENT_UI_ELEMENT_CHUNKS_SEEN_H

#include "core/download.h"

#include "element_base.h"

class Control;

namespace display {
  class WindowDownloadChunksSeen;
}

namespace ui {

class ElementChunksSeen : public ElementBase {
public:
  typedef display::WindowDownloadChunksSeen WChunksSeen;

  ElementChunksSeen(core::Download* d);

  void                activate(Control* c, MItr mItr);
  void                disable(Control* c);

private:
//   void                receive_disable();
  void                receive_next();
  void                receive_prev();
  void                receive_pagenext();
  void                receive_pageprev();

  core::Download*     m_download;
  WChunksSeen*        m_window;

  unsigned int        m_focus;
  
};

}

#endif

==> rtorrent-0.6.3.tar.gz: rtorrent-0.6.3/src/ui/element_chunks_seen.h <==
// rTorrent - BitTorrent client
// Copyright (C) 2005-2006, Jari Sundell
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// In addition, as a special exception, the copyright holders give
// permission to link the code of portions of this program with the
// OpenSSL library under certain conditions as described in each
// individual source file, and distribute linked combinations
// including the two.
//
// You must obey the GNU General Public License in all respects for
// all of the code used other than OpenSSL.  If you modify file(s)
// with this exception, you may extend this exception to your version
// of the file(s), but you are not obligated to do so.  If you do not
// wish to do so, delete this exception statement from your version.
// If you delete this exception statement from all source files in the
// program, then also delete it here.
//
// Contact:  Jari Sundell <jaris@ifi.uio.no>
//
//           Skomakerveien 33
//           3185 Skoppum, NORWAY

#ifndef RTORRENT_UI_ELEMENT_CHUNKS_SEEN_H
#define RTORRENT_UI_ELEMENT_CHUNKS_SEEN_H

#include "core/download.h"

#include "element_base.h"

class Control;

namespace display {
  class WindowDownloadChunksSeen;
}

namespace ui {

class ElementChunksSeen : public ElementBase {
public:
  typedef display::WindowDownloadChunksSeen WChunksSeen;

  ElementChunksSeen(core::Download* d);

  void                activate(display::Frame* frame, bool focus = true);
  void                disable();

  display::Window*    window();

private:
//   void                receive_disable();
  void                receive_next();
  void                receive_prev();
  void                receive_pagenext();
  void                receive_pageprev();

  core::Download*     m_download;
  WChunksSeen*        m_window;

  unsigned int        m_focus;
  
};

}

#endif
